@@ -170,7 +170,7 @@ class BasePubSubManager(ABC):
     @classmethod
     def instance(cls, handlerklass: Type[BaseSocketHandler]) -> "BasePubSubManager":
         """Get a singleton"""
-        global SUBSCRIPTIONMANAGER_SINGLETONS  # pylint: disable=W0603
+        global SUBSCRIPTIONMANAGER_SINGLETONS  # pylint: disable=W0603,W0602
         if handlerklass not in SUBSCRIPTIONMANAGER_SINGLETONS:
             SUBSCRIPTIONMANAGER_SINGLETONS[handlerklass] = cls(handlerklass)
         return SUBSCRIPTIONMANAGER_SINGLETONS[handlerklass]
@@ -213,7 +213,7 @@ class BasePubSubManager(ABC):
         topic = msgparts[0]
 
         match_found = False
-        socket_topics = (mkey[1] for mkey in self._socket_topic_map.keys() if mkey[0] == sock)
+        socket_topics = (mkey[1] for mkey in self._socket_topic_map if mkey[0] == sock)
         for stopic in socket_topics:
             if not topic.startswith(stopic):
                 continue
@@ -232,7 +232,7 @@ class BasePubSubManager(ABC):
         topic = msgparts[0]
 
         match_found = False
-        socket_topics = (mkey[1] for mkey in self._socket_topic_map.keys() if mkey[0] == sock)
+        socket_topics = (mkey[1] for mkey in self._socket_topic_map if mkey[0] == sock)
         for stopic in socket_topics:
             if not topic.startswith(stopic):
                 continue
